@@ -140,14 +140,14 @@ def import_gpxfile(gpxfile, pb):
     root = doc.getroot()
 
     radar_total=0
-    for wpt in root:
+    for wpt in root.iter(root.tag[:-3] + 'wpt'):
         radar_total += 1
     print ("Radar count : %s" % radar_total)
     import_step = 1.0/radar_total
     
     progress_status = 0.0
     i=0
-    for wpt in root:
+    for wpt in root.iter(root.tag[:-3] + 'wpt'):
         print (wpt.attrib['lat'],  wpt.attrib['lon'], wpt.find(root.tag[:-3] + 'name').text)
         mydb.insert_radar(wpt.attrib['lat'],  wpt.attrib['lon'], wpt.find(root.tag[:-3] + 'name').text)
         progress_status+=import_step
@@ -213,7 +213,7 @@ if __name__ == "__main__":
     #(result,  message) = extract_zip("/var/tmp/tmpUS8i6Croadrunner/radars.zip")
     #print message
     #import_ascfile('/var/tmp/tmpUS8i6Croadrunner/RFR.asc',  db)
-    #import_gpxfile("test/speedcamera.gpx", None)    
-    import_kmlfile("test/google_earth_scdb.kml", None)
+    import_gpxfile("test/speedcamera.gpx", None)    
+    #import_kmlfile("test/google_earth_scdb.kml", None)
     
     
